<?php
/**
 * Utilisations de pipelines par Orgchartjs
 *
 * @plugin     orgchartjs
 * @copyright  2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Orgchartjs\Pipelines
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Inserer la CSS de orgchart
 *
  * @pipeline insert_head_css
 * @param  array $flux Données du pipeline
 * @return array       Données du pipeline
 */
function orgchartjs_insert_head_css($flux){
	if (lire_config('orgchartjs/publique') != 'non') {
		// la feuille de style du plugin Org Chart pour jquery
		$flux .= '<link rel="stylesheet" type="text/css" href="'.find_in_path("orgchart-master/dist/css/jquery.orgchart.css").'" />';
		// la feuille de style du plugin Orgchart.js pour SPIP
		$flux .= '<link rel="stylesheet" type="text/css" href="'.find_in_path("css/spip_orgchartjs.css").'" />';
  	}
	return $flux;
}

/**
 * Inserer le javascript de orgchartjs
 *
 * @pipeline insert_head
 * @param  array $flux Données du pipeline
 * @return array       Données du pipeline
 */
function orgchartjs_insert_head($flux){
	if (lire_config('orgchartjs/publique') != 'non') {
		$flux .= "<script type='text/javascript' src='".find_in_path('orgchart-master/dist/js/jquery.orgchart.js')."'></script>"
			. "<script type='text/javascript' src='".find_in_path('orgchart-master/dist/js/jquery.orgchart.min.js')."'></script>";
	}
	return $flux;
}

/**
 * Activer orgchartjs dans la partie privée
 *
 * @pipeline header_prive
 * @param  array $flux Données du pipeline
 * @return array       Données du pipeline
 */
function orgchartjs_header_prive($flux){
	if (lire_config('orgchartjs/privee') != 'non') {
 		// La feuille de style style_prive_plugin_orgchartjs.html
 		// sera chargée automatiquement par SPIP. Elle vient personnaliser
		// la feuille de style d'orgchart que nous chargeons ici.
  		$flux .= '<link rel="stylesheet" type="text/css" href="'.find_in_path("orgchart-master/dist/css/jquery.orgchart.css").'" />';
 		// les javascripts
  		$flux .= "<script type='text/javascript' src='".find_in_path('orgchart-master/dist/js/jquery.orgchart.js')."'></script>"
          . "<script type='text/javascript' src='".find_in_path('orgchart-master/dist/js/jquery.orgchart.min.js')."'></script>";
	}
	return $flux;
}

/**
 * Ajoute à la présentation textuelle de la hierarchie, une présentation graphique.
 * 
 * En relation avec le contenu affiché, affichage (graphique) de la hiérarchie.
 * Par défaut, l'ascendance en ligne droite.
 * 
 * @pipeline affiche_hierarchie
 * @param  array $flux Données du pipeline
 * @return array       Données du pipeline
 */

function orgchartjs_affiche_hierarchie($flux) {
	if (($objet = $flux['args']['objet']) AND ($id_objet = $flux['args']['id_objet']) AND (in_array('haut',lire_config('orgchartjs/localisation',array())))) {
		$graphique = '';
		if ( find_in_path("prive/squelettes/inclure/vue_orgchartjs_${objet}.html") AND (!in_array('non',lire_config('orgchartjs/hierarchie',array())))) {
			// vue spécifique
			$graphique = "<div style='height: 200px;'>" .
				recuperer_fond("prive/squelettes/inclure/vue_orgchartjs_${objet}", array(
					'exec' => $objet,
					'objet'=> $objet,
					'id_objet'=> $id_objet,
					'orgchartjs'=> 'chemin',
					'direction'=> 'l2r' // left to right, dans la langue de Shakespeare
				)).
				"</div>";
		} elseif (!in_array('specifique',lire_config('orgchartjs/hierarchie',array()))) {
				// vue par défaut
			$graphique = "<div style='height: 200px;'>" . 
				recuperer_fond('prive/squelettes/inclure/vue_orgchartjs', array(
						'exec' => $objet,
						'objet'=> $objet,
						'id_objet'=> $id_objet,
						'orgchartjs'=> 'chemin',
						'direction'=> 'l2r' // left to right, dans la langue de Shakespeare
				)).
				"</div>";
		}

		if (lire_config('orgchartjs/substitution') == 'on'){
			$flux['data'] = $graphique;
		} else {
			$flux['data'] .= $graphique;
		}
	}
	return $flux;
}

/**
 * Ajouter du contenu dans la colonne « droite » des pages de l’espace privé.
 * 
 * En relation avec le contenu affiché, affichage (graphique) de la hiérarchie.
 * Par défaut, l'ascendance en ligne droite.
 * 
 * @use API presentation (inc/presentation)
 * 
 * @pipeline affiche_droite
 * @param  array $flux Données du pipeline
 * @return array       Données du pipeline
 */
function orgchartjs_affiche_droite($flux) {

	if (isset($flux['args']['exec'])) {

		$exec = trouver_objet_exec($flux['args']['exec']);

		// exec d'un objet éditorial : si la configuration le souhaite, on affiche graphiquement la hiérarchie.
		if (
			($exec['edition'] !== true) // page visu
			and (in_array('droite',lire_config('orgchartjs/localisation',array())))
			and ($id_table = $exec['id_table_objet']) // colonne id_ (ex: id_article)
			and ($objet = $exec['type']) // objet (ex: article)
			and isset($flux['args'][$id_table]) // numéro d'identifiant unique
			and ($id_objet = intval($flux['args'][$id_table]))
		) {
			include_spip('inc/presentation');
			if (find_in_path("prive/squelettes/inclure/vue_orgchartjs_${objet}.html")) {
				// vue spécifique
				$flux['data'] .= debut_cadre_relief('orgchartjs-24.png', true, '', _T("${objet}:titre_orgchartjs")) .
				"<div class='center'>" .
				recuperer_fond("prive/squelettes/inclure/vue_orgchartjs_${objet}", array(
					'exec' => $exec['type'],
					'objet'=> $objet,
					'id_objet'=> $id_objet
				)) .
				"</div>" .
				fin_cadre_relief(true);
			} elseif (!in_array('specifique',lire_config('orgchartjs/hierarchie',array()))) {
				// vue par défaut
				$flux['data'] .= debut_cadre_relief('orgchartjs-24.png', true, '', _T('orgchartjs:titre_orgchartjs')) .
					"<div class='center'>" .
					recuperer_fond('prive/squelettes/inclure/vue_orgchartjs', array(
						'exec' => $exec['type'],
						'objet'=> $objet,
						'id_objet'=> $id_objet
					)) .
					"</div>" .
					fin_cadre_relief(true);
			}
		}

	}
	return $flux;
}

/**
 * Ajouter du contenu dans la colonne « gauche » des pages de l’espace privé.
 * 
 * En relation avec le contenu affiché, affichage (graphique) de la hiérarchie.
 * Par défaut, l'ascendance en ligne droite.
 * 
 * @use API presentation (inc/presentation)
 * 
 * @pipeline affiche_gauche
 * @param  array $flux Données du pipeline
 * @return array       Données du pipeline
 */
function orgchartjs_affiche_gauche($flux) {

	if (isset($flux['args']['exec'])) {

		$exec = trouver_objet_exec($flux['args']['exec']);

		// exec d'un objet éditorial : si la configuration le souhaite, on affiche graphiquement la hiérarchie.
		if (
			($exec['edition'] !== true) // page visu
			and (in_array('gauche',lire_config('orgchartjs/localisation',array())))
			and ($id_table = $exec['id_table_objet']) // colonne id_ (ex: id_article)
			and ($objet = $exec['type']) // objet (ex: article)
			and isset($flux['args'][$id_table]) // numéro d'identifiant unique
			and ($id_objet = intval($flux['args'][$id_table]))
		) {
			include_spip('inc/presentation');
			if (find_in_path("prive/squelettes/inclure/vue_orgchartjs_${objet}.html")) {
				// vue spécifique
				$flux['data'] .= debut_cadre_relief('orgchartjs-24.png', true, '', _T("${objet}:titre_orgchartjs")) .
				"<div class='center'>" .
				recuperer_fond("prive/squelettes/inclure/vue_orgchartjs_${objet}", array(
					'exec' => $exec['type'],
					'objet'=> $objet,
					'id_objet'=> $id_objet
				)) .
				"</div>" .
				fin_cadre_relief(true);
			} elseif (!in_array('specifique',lire_config('orgchartjs/hierarchie',array()))) {
				// vue par défaut
				$flux['data'] .= debut_cadre_relief('orgchartjs-24.png', true, '', _T('orgchartjs:titre_orgchartjs')) .
					"<div class='center'>" .
					recuperer_fond('prive/squelettes/inclure/vue_orgchartjs', array(
						'exec' => $exec['type'],
						'objet'=> $objet,
						'id_objet'=> $id_objet
					)) .
					"</div>" .
					fin_cadre_relief(true);
			}
		}

	}
	return $flux;
}